@@ -65,14 +65,6 @@ class Resource(AttributesMixin):
 
         return self._get_resource(**kwargs)
 
-    async def __aenter__(self):
-        """Asyncio with enter."""
-        return self
-
-    async def __aexit__(self, exc_type, exc, tb):
-        """Asyncio with exit."""
-        self._store["session"].close()
-
     async def _request(self, method, data=None, file=None, headers=None, params=None):
         serializer = self._store["serializer"]
         url = self.url
@@ -96,9 +88,9 @@ class Resource(AttributesMixin):
 
         if 400 <= resp.status <= 499:
             exception_class = exceptions.HttpNotFoundError if resp.status == 404 else exceptions.HttpClientError
-            raise exception_class("Client Error %s: %s" % (resp.status, url), response=resp, content=resp.content)
+            raise exception_class("Client Error %s: %s" % (resp.status, url), response=resp, content=await self._try_to_serialize_response(resp))
         elif 500 <= resp.status <= 599:
-            raise exceptions.HttpServerError("Server Error %s: %s" % (resp.status, url), response=resp, content=resp.content)
+            raise exceptions.HttpServerError("Server Error %s: %s" % (resp.status, url), response=resp, content=await self._try_to_serialize_response(resp))
 
         return resp
 
@@ -108,8 +100,8 @@ class Resource(AttributesMixin):
             return
 
         content = await resp.read()
-        if resp.headers.get("content-type", None) and content:
-            content_type = resp.headers.get("content-type").split(";")[0].strip()
+        if resp.headers.get("Content-Type", None) and content:
+            content_type = resp.headers.get("Content-Type").split(";")[0].strip()
 
             try:
                 # get serializer
@@ -217,6 +209,14 @@ class API(AttributesMixin):
         if self._store.get("base_url") is None:
             raise exceptions.ImproperlyConfigured("base_url is required")
 
+    async def __aenter__(self):
+        """Asyncio with enter."""
+        return self
+
+    async def __aexit__(self, exc_type, exc, tb):
+        """Asyncio with exit."""
+        await self.close()
+
     async def close(self):
         """Close underlying session."""
         await self._store['session'].close()
